/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla-russia.org code.
 *
 * The Initial Developer of the Original Code is
 * Alexey Gladkov <legion@mozilla-russia.org>
 *
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const PRIORITY = "alt_exec_priority";
const DESCRIPTION = "alt_exec_description";
const ERRORMESSAGE = "alt_exec_error_message";
const COMMAND = "alt_exec_command";
const EVENT_NAME = "alt-exec-message";
const SCRIPT_DIR = "/var/lib/alterator/tickets/";

var inEventListener = null;
var gErrorMessage = null;
var gBrowser = document.getElementById("content");

gBrowser.addEventListener("pageshow", altListener, false);

function getPriority(aDoc)
{
	var notificationBox = gBrowser.getNotificationBox();
	var priority = aDoc.getElementsByName(PRIORITY)[0];

	if (!priority)
		return notificationBox.PRIORITY_WARNING_LOW;

	switch(priority.value) {
		case "info-low":	return notificationBox.PRIORITY_INFO_LOW;
		case "info-medium":	return notificationBox.PRIORITY_INFO_MEDIUM;
		case "info-high":	return notificationBox.PRIORITY_INFO_HIGH;
		case "warning-low":	return notificationBox.PRIORITY_WARNING_LOW;
		case "warning-medium":	return notificationBox.PRIORITY_WARNING_MEDIUM;
		case "warning-high":	return notificationBox.PRIORITY_WARNING_HIGH;
		case "critical-low":	return notificationBox.PRIORITY_CRITICAL_LOW;
		case "critical-medium":	return notificationBox.PRIORITY_CRITICAL_MEDIUM;
		case "critical-high":	return notificationBox.PRIORITY_CRITICAL_HIGH;
		case "critical-block":	return notificationBox.PRIORITY_CRITICAL_BLOCK;
	}
}

function initFile(aFileName)
{
	if (!aFileName) return false;
	var file = Components.classes["@mozilla.org/file/local;1"]
	                     .createInstance(Components.interfaces.nsILocalFile);
	file.initWithPath(SCRIPT_DIR + aFileName);
	return file;
}

function Execute(aFileName)
{
	var file = initFile(aFileName);

	if (!file.exists())
		return;

	try {
		var proc = Components.classes["@mozilla.org/process/util;1"]
		                     .createInstance(Components.interfaces.nsIProcess);
		proc.init(file);
		proc.run(true, [], 0);
	}
	catch(e) {
		if (gErrorMessage) alert (gErrorMessage);
	}
}

function makeCallBack(aKey)
{
	return function() { Execute(aKey); return true; };
}

function altListener(aArg)
{
	var doc = gBrowser.contentDocument;

	if (doc.URL == "about:blank") return;

	var bdDescr = doc.getElementsByName(DESCRIPTION)[0];
	if (!bdDescr) return;

	var bdCmds = doc.getElementsByName(COMMAND);
	if (!bdCmds.length) return;

	var buttons = new Array();
	for (var i = 0; i < bdCmds.length; i++) {
		var cmd = bdCmds[i].value.split(';');

		if (initFile(cmd[0]).exists())
			buttons.push({
				label: decodeURIComponent(cmd[1]),
				accessKey: null,
				popup: null,
				callback: makeCallBack(cmd[0])
			});
	}

	if (!buttons.length) return;

	// Optional parameter
	var err = doc.getElementsByName(ERRORMESSAGE)[0];
	if (err)
		gErrorMessage = decodeURIComponent(err.value);

	var notificationBox = gBrowser.getNotificationBox();
	var notification = notificationBox.getNotificationWithValue(EVENT_NAME);
	if (notification)
		notificationBox.removeNotification(notification);

	notificationBox.appendNotification(decodeURIComponent(bdDescr.value),
					EVENT_NAME,
					"chrome://altExtension/skin/altlinux-mini.png",
					getPriority(doc),
					buttons);
}
